summaryrefslogtreecommitdiff
path: root/lisp
diff options
context:
space:
mode:
authorMiles Bader <miles@gnu.org>2005-01-22 21:39:38 +0000
committerMiles Bader <miles@gnu.org>2005-01-22 21:39:38 +0000
commit18643d1d412928c57690271c8b7a65e50503441f (patch)
treea9303ce501314fc316c20ca29928b2fa168d0421 /lisp
parentcfa4901a57cc9920eec0401d8b33abac7d3f8e5b (diff)
parentddff82cf89b20912729a1483da3f28608b44115a (diff)
downloademacs-18643d1d412928c57690271c8b7a65e50503441f.tar.gz
emacs-18643d1d412928c57690271c8b7a65e50503441f.tar.bz2
emacs-18643d1d412928c57690271c8b7a65e50503441f.zip
Revision: miles@gnu.org--gnu-2005/emacs--unicode--0--patch-4
Merge from emacs--cvs-trunk--0 Patches applied: * miles@gnu.org--gnu-2005/emacs--cvs-trunk--0--patch-41 - miles@gnu.org--gnu-2005/emacs--cvs-trunk--0--patch-46 Update from CVS * miles@gnu.org--gnu-2005/emacs--cvs-trunk--0--patch-47 Merge from gnus--rel--5.10 * miles@gnu.org--gnu-2005/gnus--rel--5.10--patch-4 Merge from emacs--cvs-trunk--0 * miles@gnu.org--gnu-2005/gnus--rel--5.10--patch-5 Update from CVS: exi/gnus-faq.texi ([4.1]): Typo. * miles@gnu.org--gnu-2005/gnus--rel--5.10--patch-6 Update from CVS
Diffstat (limited to 'lisp')
-rw-r--r--lisp/ChangeLog282
-rw-r--r--lisp/bindings.el12
-rw-r--r--lisp/calc/calc-ext.el10
-rw-r--r--lisp/calc/calc-prog.el12
-rw-r--r--lisp/calc/calc-yank.el3
-rw-r--r--lisp/calc/calc.el2
-rw-r--r--lisp/case-table.el4
-rw-r--r--lisp/emacs-lisp/lisp.el12
-rw-r--r--lisp/gnus/ChangeLog7
-rw-r--r--lisp/gnus/mm-decode.el27
-rw-r--r--lisp/hilit-chg.el6
-rw-r--r--lisp/net/eudc.el2
-rw-r--r--lisp/net/tramp-smb.el57
-rw-r--r--lisp/net/tramp-util.el68
-rw-r--r--lisp/net/tramp-vc.el9
-rw-r--r--lisp/net/tramp.el88
-rw-r--r--lisp/net/trampver.el2
-rw-r--r--lisp/pcomplete.el8
-rw-r--r--lisp/play/decipher.el3
-rw-r--r--lisp/progmodes/gdb-ui.el130
-rw-r--r--lisp/progmodes/grep.el6
-rw-r--r--lisp/progmodes/sh-script.el6
-rw-r--r--lisp/ses.el47
-rw-r--r--lisp/simple.el31
-rw-r--r--lisp/subr.el31
-rw-r--r--lisp/term/mac-win.el7
-rw-r--r--lisp/textmodes/ispell.el16
-rw-r--r--lisp/textmodes/org.el4
-rw-r--r--lisp/textmodes/tex-mode.el4
-rw-r--r--lisp/type-break.el5
-rw-r--r--lisp/url/ChangeLog5
-rw-r--r--lisp/url/url-http.el2
-rw-r--r--lisp/window.el10
-rw-r--r--lisp/xt-mouse.el14
34 files changed, 641 insertions, 291 deletions
diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index fa3006178b1..0be81220340 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,186 @@
+2005-01-22 David Kastrup <dak@gnu.org>
+
+ * progmodes/grep.el: Add alias `find-grep' for `grep-find'.
+
+2005-01-22 Eli Zaretskii <eliz@gnu.org>
+
+ * type-break.el (type-break-mode): Add a test for
+ type-break-file-name being non-nil.
+
+2005-01-22 Toby Allsopp <Toby.Allsopp@navman.com> (tiny change)
+
+ * net/eudc.el (top level): Call (message "") via progn, so that
+ eudc-options-file is loaded.
+
+2005-01-22 Kim F. Storm <storm@cua.dk>
+
+ * simple.el (line-move-1): Rename from line-move.
+ (line-move): New function that adjusts vscroll for partially
+ visible rows, and calls line-move-1 otherwise.
+
+2005-01-21 Ren,Ai(B Kyllingstad <listmailxemacs@kyllingstad.com>
+
+ * pcomplete.el: define pcomplete-read-event instead of read-event,
+ since it's not a complete read-event implementation
+
+2005-01-20 Jay Belanger <belanger@truman.edu>
+
+ * calc/calc-ext.el (calc-fancy-prefix-other-key): Set prefix arg
+ for called function.
+
+2005-01-20 Steven Tamm <steventamm@mac.com>
+
+ * term/mac-win.el (process-connection-type): Removed.
+ Controlled now by s/darwin.h:PTY_ITERATION.
+
+2005-01-20 Stefan Monnier <monnier@iro.umontreal.ca>
+
+ * window.el (handle-select-window): Don't switch window when we're
+ in the minibuffer.
+
+2005-01-10 Paul Pogonyshev <pogonyshev@gmx.net>
+
+ * subr.el (dotimes-with-progress-reporter): New macro.
+
+ * ses.el (ses-dotimes-msg): Remove macro.
+ Use `dotimes-with-progress-reporter' instead.
+
+2005-01-19 Steven Tamm <steventamm@mac.com>
+
+ * term/mac-win.el (process-connection-type): Use new
+ operating-system-release variable to use ptys on Darwin 7 (OSX
+ 10.3) when using carbon build.
+
+2005-01-19 Jay Belanger <belanger@truman.edu>
+
+ * calc/calc-ext.el (calc-fancy-prefix-other-key): Don't clear
+ flags if the last command was a tab or M-tab.
+
+ * calc/calc-prog.el (calc-user-define-edit): Put original formula
+ in formula editing buffer.
+
+2005-01-19 Nick Roberts <nickrob@snap.net.nz>
+
+ * progmodes/gdb-ui.el (gdb-put-breakpoint-icon): Add help-echo for
+ breakpoint image symbol in margin.
+
+2005-01-19 Jay Belanger <belanger@truman.edu>
+
+ * calc/calc-prog.el (calc-execute-kbd-macro):
+ Ignore calc-keep-arg-flag.
+
+2005-01-19 Kenichi Handa <handa@m17n.org>
+
+ * textmodes/ispell.el (ispell-looking-at): New function.
+ (ispell-process-line): Use ispell-looking-at to compare the ispell
+ output and the buffer contents.
+
+2005-01-18 Jay Belanger <belanger@truman.edu>
+
+ * calc/calc.el (calc-display-raw): Fix docstring.
+
+2005-01-18 Stefan Monnier <monnier@iro.umontreal.ca>
+
+ * simple.el (blink-matching-open): Strip extra info from syntax.
+
+ * progmodes/sh-script.el (sh-here-doc-open-re): Don't allow | or other
+ funny chars in the end-of-here-doc marker.
+
+2005-01-19 Nick Roberts <nickrob@snap.net.nz>
+
+ * progmodes/gdb-ui.el (gdb-put-string): Copy/create strings so
+ that enable/disabled state of breakpoints is shown correctly in
+ fringe and on ttys.
+ (gdb-put-breakpoint-icon, gdb-info-breakpoints-custom):
+ Add breakpoint information as text properties.
+ (gdb-mouse-toggle-breakpoint):
+ Rename to gdb-mouse-set-clear-breakpoint.
+ (gdb-mouse-toggle-breakpoint): New function. Enable/disable
+ breakpoints in the margin.
+ (gdb-remove-strings): Simplify.
+
+2005-01-17 Jay Belanger <belanger@truman.edu>
+
+ * calc/calc-yank.el (calc-edit-mode): Inhibit read-only when
+ erasing buffer.
+
+2005-01-17 Richard M. Stallman <rms@gnu.org>
+
+ * progmodes/grep.el (grep-find): Copy from `grep' the condition
+ for calling grep-compute-defaults.
+
+ * play/decipher.el (decipher-mode): Don't call decipher-read-alphabet
+ if buffer is empty.
+
+ * emacs-lisp/lisp.el (backward-kill-sexp, kill-sexp): Doc fixes.
+
+2005-01-17 Stefan Monnier <monnier@iro.umontreal.ca>
+
+ * hilit-chg.el (highlight-changes-mode): Don't autoload.
+
+ * bindings.el (mode-line-mode-menu): Use bound-and-true-p for all the
+ non-preloaded variables.
+
+2005-01-17 Steven Tamm <steventamm@mac.com>
+
+ * textmodes/tex-mode.el (tex-start-shell): Adding -i to the
+ tex-shell cause to force interactivity when using pipes.
+
+2005-01-17 Kim F. Storm <storm@cua.dk>
+
+ * simple.el (just-one-space): Make arg optional.
+
+2005-01-17 Nick Roberts <nickrob@snap.net.nz>
+
+ * xt-mouse.el (xterm-mouse-event): Set new optional fourth arg in
+ posn-at-x-y to t to access left-margin.
+
+2005-01-16 Michael Albinus <michael.albinus@gmx.de>
+
+ Sync with Tramp 2.0.47.
+
+ * tramp.el (tramp-operation-not-permitted-regexp) New defcustom,
+ catching keep-date problems in cp/scp operations.
+ (tramp-handle-copy-file): Don't call `set-file-modes'
+ unconditionally. Specialized functions should know better what is
+ necessary. This improves performance a little bit, and the
+ functions could catch errors with `cp -p' and `scp -p'.
+ (tramp-do-copy-or-rename-file-via-buffer)
+ (tramp-do-copy-or-rename-file-out-of-band): Call `set-file-modes'
+ when appropriate.
+ (tramp-do-copy-or-rename-file-directly): Mask `cp -p' error.
+ Call `set-file-modes' when appropriate.
+ (tramp-action-out-of-band): Mask `scp -p' error. Reported by Isak
+ Johnsson <isak@hypergene.com>
+ (tramp-get-buffer, tramp-get-debug-buffer): Discard the undo list
+ of both Tramp buffer and debug buffer. Reported by Joakim Verona
+ <joakim@verona.se>
+ (tramp-file-name-for-operation): Mark `shell-command' as magic for
+ Emacs only.
+
+ * tramp-util.el (tramp-minor-mode): New minor mode. Add it to
+ `find-file-hooks' and `dired-mode-hook'.
+ (tramp-minor-mode-map): Respective map. Add remapping for
+ `compile' and `recompile'.
+ (tramp-remap-command, tramp-recompile): New defuns.
+ (tramp-compile): Enable `tramp-minor-mode' and `compilation-mode'
+ in buffer "*Compilation*". Call the commands asynchronously.
+
+ * tramp-vc.el (tramp-vc-do-command, tramp-vc-do-command-new)
+ (tramp-vc-simple-command): Call `tramp-handle-shell-command' but
+ `shell-command', because it isn't magic in XEmacs. Reported by
+ Adrian Aichner <adrian@xemacs.org>.
+
+ * tramp-smb.el (tramp-smb-file-name-handler-alist): Add entry for
+ `substitute-in-file-name.
+ (tramp-smb-handle-substitute-in-file-name): New defun.
+ (tramp-smb-advice-PC-do-completion): Delete advice.
+
+2005-01-16 Kai Grossjohann <kgrossjo@eu.uu.net>
+
+ * tramp.el (tramp-wait-for-output): Fix typo in echo processing.
+ Fix error in deleting region.
+
2005-01-15 Richard M. Stallman <rms@gnu.org>
* emacs-lisp/lisp-mnt.el (lm-with-file): Use Lisp mode in temp buffer.
@@ -24,28 +207,26 @@
(sh-mode-map): Bind C-c C-\.
(sh-backslash-column, sh-backslash-align): New variables.
(sh-backslash-region, sh-append-backslash): New functions.
-
+
2005-01-15 Sergey Poznyakoff <gray@Mirddin.farlep.net>
* mail/rmail.el: Updated to work with movemail from GNU Mailutils
- (rmail-pop-password, rmail-pop-password-required): Moved to
+ (rmail-pop-password, rmail-pop-password-required): Move to
rmail-obsolete group.
- (rmail-set-pop-password): Renamed to rmail-set-remote-password.
+ (rmail-set-pop-password): Rename to rmail-set-remote-password.
All callers updated.
- (rmail-get-pop-password): Renamed to rmail-get-remote-password.
+ (rmail-get-pop-password): Rename to rmail-get-remote-password.
Take an argument specifying whether it is POP or IMAP mailbox we
are using. All callers updated.
- (rmail-pop-password-error): Renamed to
- rmail-remote-password-error. Added mailutils-specific error
- message.
+ (rmail-pop-password-error): Rename to
+ rmail-remote-password-error. Added mailutils-specific error message.
(rmail-movemail-search-path)
(rmail-movemail-variant-in-use): New variables.
- (rmail-remote-password, rmail-remote-password-required): New
- customization variables.
- (rmail-probe,rmail-autodetect, rmail-movemail-variant-p): New
- functions.
+ (rmail-remote-password, rmail-remote-password-required):
+ New customization variables.
+ (rmail-probe,rmail-autodetect, rmail-movemail-variant-p): New funs.
(rmail-parse-url): New function.
- (rmail-get-new-mail, rmail-insert-inbox-text): Updated for use
+ (rmail-get-new-mail, rmail-insert-inbox-text): Update for use
with GNU mailutils movemail.
2005-01-15 Kevin Ryde <user42@zip.com.au>
@@ -57,8 +238,8 @@
2005-01-15 Jorgen Schaefer <forcer@forcix.cx> (tiny change)
* type-break.el (type-break-mode, type-break-file-time)
- (type-break-file-keystroke-count, type-break-choose-file): Don't
- store data in or load data from the file if type-break-file-name
+ (type-break-file-keystroke-count, type-break-choose-file):
+ Don't store data in or load data from the file if type-break-file-name
is nil.
(type-break-file-name): Doc update as per the above.
@@ -70,8 +251,7 @@
2005-01-15 Alan Mackenzie <acm@muc.de>
* ebrowse.el (ebrowse-class-in-tree): Return the tail of the tree
- rather than the element found, thus enabling the tree to be
- setcar'd.
+ rather than the element found, thus enabling the tree to be setcar'd.
2005-01-14 Carsten Dominik <dominik@science.uva.nl>
@@ -89,62 +269,59 @@
* textmodes/org.el (org-mode): `org-table-may-need-update' is now
a local variable in each org-mode buffer.
- * textmodes/org.el (org-set-regexps-and-options): Renamed from
+ * textmodes/org.el (org-set-regexps-and-options): Rename from
`org-set-regexps'. Added checking for STARTUP keyword.
- (org-get-current-options): Added STARTUP options.
+ (org-get-current-options): Add STARTUP options.
(org-table-insert-row): Mode mode intelligent about when
realignment is needed.
- (org-self-insert-command, org-delete-backward-char,
- org-delete-char): New commands.
- (org-enable-table-editor): new default value `optimized'.
+ (org-self-insert-command, org-delete-backward-char, org-delete-char):
+ New commands.
+ (org-enable-table-editor): New default value `optimized'.
(org-table-blank-field): Support blanking regions if active.
-
2005-01-14 Carsten Dominik <dominik@science.uva.nl>
* textmodes/reftex-cite.el (reftex-bib-sort-year): Catch the case
if the year is not given.
- * textmodes/reftex-ref.el (reftex-replace-prefix-escapes): Added
- new escapes %m and %M, fixed bug with %F by adding
+ * textmodes/reftex-ref.el (reftex-replace-prefix-escapes):
+ Add new escapes %m and %M, fixed bug with %F by adding
save-match-data.
- (reftex-reference): Removed ?. from list of spaces.
- (reftex-label-info): Added automatic label prefix recognition
-
- * textmodes/reftex-index.el (reftex-index-next-phrase): Added
- slave parameter to call of `reftex-index-this-phrase'
- (reftex-index-this-phrase): New optional argument
- (reftex-index-region-phrases): Added slave parameter to call of
- `reftex-index-this-phrase'
- (reftex-display-index): New argument redo
- (reftex-index-rescan): Added 'redo to arguments of
- `reftex-display-index'
+ (reftex-reference): Remove ?. from list of spaces.
+ (reftex-label-info): Add automatic label prefix recognition.
+
+ * textmodes/reftex-index.el (reftex-index-next-phrase):
+ Add slave parameter to call of `reftex-index-this-phrase'.
+ (reftex-index-this-phrase): New optional argument.
+ (reftex-index-region-phrases): Add slave parameter to call of
+ `reftex-index-this-phrase'.
+ (reftex-display-index): New argument redo.
+ (reftex-index-rescan): Add 'redo to arguments of
+ `reftex-display-index'.
(reftex-index-Rescan, reftex-index-revert)
- (reftex-index-switch-index-tag): Added 'redo to arguments of
- `reftex-display-index'
- (reftex-index-make-phrase-regexp): Fixed bug with case-sensitive
- indexing. Fixed bug with matching is there is a quote before or
+ (reftex-index-switch-index-tag): Add 'redo to arguments of
+ `reftex-display-index'.
+ (reftex-index-make-phrase-regexp): Fix bug with case-sensitive
+ indexing. Fix bug with matching is there is a quote before or
after the word.
- * textmodes/reftex-cite.el (reftex-all-used-citation-keys): Fix
- bug when collecting citation keys in lines with comments.
+ * textmodes/reftex-cite.el (reftex-all-used-citation-keys):
+ Fix bug when collecting citation keys in lines with comments.
(reftex-citation): Prefix argument no longer rescans the document,
but forces prompting for optional arguments of cite macros.
- (reftex-do-citation): Prompting for optional arguments
- implemented.
+ (reftex-do-citation): Prompting for optional arguments implemented.
- * textmodes/reftex-vars.el (reftex-cite-format-builtin): Added
- optional arguments to most cite commands.
+ * textmodes/reftex-vars.el (reftex-cite-format-builtin):
+ Add optional arguments to most cite commands.
(reftex-cite-cleanup-optional-args): New option
(reftex-cite-prompt-optional-args): New option.
- (reftex-trust-label-prefix): New option
+ (reftex-trust-label-prefix): New option.
- * textmodes/reftex-toc.el (reftex-toc-find-section): Added
- push-mark before changing the position in the buffer.
+ * textmodes/reftex-toc.el (reftex-toc-find-section):
+ Add push-mark before changing the position in the buffer.
- * textmodes/reftex.el (reftex-prefix-to-typekey-alist): New
- variable
- (reftex-compile-variables): Compute reftex-prefix-to-typekey-alist
+ * textmodes/reftex.el (reftex-prefix-to-typekey-alist): New variable.
+ (reftex-compile-variables): Compute reftex-prefix-to-typekey-alist.
2005-01-14 Nick Roberts <nickrob@snap.net.nz>
@@ -6229,8 +6406,7 @@
* progmodes/cperl-mode.el (cperl-mode): Adapt defun-prompt-regexp
so that it is more understanding of whitespace.
- * xml.el (xml-maybe-do-ns, xml-parse-tag): Produce elements in the
- form
+ * xml.el (xml-maybe-do-ns, xml-parse-tag): Produce elements in the form
(("ns" . "element") (attr-list) children) instead of
((:ns . "element") (attr-list) children) in order to reduce the
number of symbols used.
diff --git a/lisp/bindings.el b/lisp/bindings.el
index 93921c6f982..9c95d618a23 100644
--- a/lisp/bindings.el
+++ b/lisp/bindings.el
@@ -1,7 +1,7 @@
;;; bindings.el --- define standard key bindings and some variables
-;; Copyright (C) 1985,86,87,92,93,94,95,96,99,2000, 2001
-;; Free Software Foundation, Inc.
+;; Copyright (C) 1985, 1986, 1987, 1992, 1993, 1994, 1995, 1996, 1999, 2000,
+;; 2001, 2005 Free Software Foundation, Inc.
;; Maintainer: FSF
;; Keywords: internal
@@ -403,7 +403,7 @@ Menu of mode operations in the mode line.")
:button (:toggle . line-number-mode)))
(define-key mode-line-mode-menu [highlight-changes-mode]
`(menu-item ,(purecopy "Highlight changes (Chg)") highlight-changes-mode
- :button (:toggle . highlight-changes-mode)))
+ :button (:toggle . (bound-and-true-p highlight-changes-mode))))
(define-key mode-line-mode-menu [hide-ifdef-mode]
`(menu-item ,(purecopy "Hide ifdef (Ifdef)") hide-ifdef-mode
:button (:toggle . (bound-and-true-p hide-ifdef-mode))))
@@ -421,10 +421,10 @@ Menu of mode operations in the mode line.")
:button (:toggle . column-number-mode)))
(define-key mode-line-mode-menu [auto-revert-tail-mode]
`(menu-item ,(purecopy "Auto revert tail (Tail)") auto-revert-tail-mode
- :button (:toggle . auto-revert-tail-mode)))
+ :button (:toggle . (bound-and-true-p auto-revert-tail-mode))))
(define-key mode-line-mode-menu [auto-revert-mode]
`(menu-item ,(purecopy "Auto revert (ARev)") auto-revert-mode
- :button (:toggle . auto-revert-mode)))
+ :button (:toggle . (bound-and-true-p auto-revert-mode))))
(define-key mode-line-mode-menu [auto-fill-mode]
`(menu-item ,(purecopy "Auto fill (Fill)") auto-fill-mode
:button (:toggle . auto-fill-function)))
@@ -1012,5 +1012,5 @@ language you are using."
;; no-update-autoloads: t
;; End:
-;;; arch-tag: 23b5c7e6-e47b-49ed-8c6c-ed213c5fffe0
+;; arch-tag: 23b5c7e6-e47b-49ed-8c6c-ed213c5fffe0
;;; bindings.el ends here
diff --git a/lisp/calc/calc-ext.el b/lisp/calc/calc-ext.el
index 280c3ca634b..8d3be3b8505 100644
--- a/lisp/calc/calc-ext.el
+++ b/lisp/calc/calc-ext.el
@@ -1394,10 +1394,14 @@ calc-kill calc-kill-region calc-yank))))
(defun calc-fancy-prefix-other-key (arg)
(interactive "P")
- (if (or (not (integerp last-command-char))
- (and (>= last-command-char 0) (< last-command-char ? )
- (not (eq last-command-char meta-prefix-char))))
+ (if (and
+ (not (eq last-command-char 'tab))
+ (not (eq last-command-char 'M-tab))
+ (or (not (integerp last-command-char))
+ (and (>= last-command-char 0) (< last-command-char ? )
+ (not (eq last-command-char meta-prefix-char)))))
(calc-wrapper)) ; clear flags if not a Calc command.
+ (setq prefix-arg arg)
(calc-unread-command)
(setq overriding-terminal-local-map nil))
diff --git a/lisp/calc/calc-prog.el b/lisp/calc/calc-prog.el
index b4901b5f8a0..a37f3c5cedd 100644
--- a/lisp/calc/calc-prog.el
+++ b/lisp/calc/calc-prog.el
@@ -702,15 +702,17 @@
(intcmd (symbol-name (cdr def)))
(algcmd (substring (symbol-name func) 9)))
(if (and defn (calc-valid-formula-func func))
- (progn
+ (let ((niceexpr (math-format-nice-expr defn (frame-width))))
(calc-wrapper
(calc-edit-mode
(list 'calc-finish-formula-edit (list 'quote func))
nil
- (format "Editing formula (%s, %s, bound to %s).\n"
- intcmd algcmd kys))
+ (format (concat
+ "Editing formula (%s, %s, bound to %s).\n"
+ "Original formula: %s\n")
+ intcmd algcmd kys niceexpr))
(insert (math-showing-full-precision
- (math-format-nice-expr defn (frame-width)))
+ niceexpr)
"\n"))
(calc-show-edit-buffer))
(error "That command's definition cannot be edited")))))))
@@ -1124,6 +1126,8 @@ Redefine the corresponding command."
(calc-execute-kbd-macro last-kbd-macro arg))
(defun calc-execute-kbd-macro (mac arg &rest prefix)
+ (if calc-keep-args-flag
+ (calc-keep-args))
(if (and (vectorp mac) (> (length mac) 0) (stringp (aref mac 0)))
(setq mac (or (aref mac 1)
(aset mac 1 (progn (and (fboundp 'edit-kbd-macro)
diff --git a/lisp/calc/calc-yank.el b/lisp/calc/calc-yank.el
index 53d5946e073..339dfd838a4 100644
--- a/lisp/calc/calc-yank.el
+++ b/lisp/calc/calc-yank.el
@@ -460,7 +460,8 @@ To cancel the edit, simply kill the *Calc Edit* buffer."
(setq calc-restore-trail (get-buffer-window (calc-trail-buffer)))
(make-local-variable 'calc-allow-ret)
(setq calc-allow-ret allow-ret)
- (erase-buffer)
+ (let ((inhibit-read-only t))
+ (erase-buffer))
(add-hook 'kill-buffer-hook (lambda ()
(let ((calc-edit-handler nil))
(calc-edit-finish t))
diff --git a/lisp/calc/calc.el b/lisp/calc/calc.el
index a578a8666b8..ba5cda831e1 100644
--- a/lisp/calc/calc.el
+++ b/lisp/calc/calc.el
@@ -438,7 +438,7 @@ If `units', `math-simplify-units' is applied.")
"If non-nil, recompute evalto's automatically when necessary.")
(defcalcmodevar calc-display-raw nil
- "If non-nil, display shows unformatted Lisp exprs.(defcalcmodevar For debugging)")
+ "If non-nil, display shows unformatted Lisp exprs. (For debugging)")
(defcalcmodevar calc-internal-prec 12
"Number of digits of internal precision for calc-mode calculations.")
diff --git a/lisp/case-table.el b/lisp/case-table.el
index 71e82bcabef..747e90c28f5 100644
--- a/lisp/case-table.el
+++ b/lisp/case-table.el
@@ -95,6 +95,8 @@ It also modifies `standard-syntax-table' to give them the syntax of
word constituents."
(aset table uc lc)
(aset table lc lc)
+ ;; Clear out the extra slots so that they will be
+ ;; recomputed from the main (downcase) table.
(set-char-table-extra-slot table 0 nil)
(set-char-table-extra-slot table 1 nil)
(set-char-table-extra-slot table 2 nil)
@@ -108,6 +110,8 @@ that will be used as the downcase part of a case table.
It also modifies `standard-syntax-table'.
SYNTAX should be \" \", \"w\", \".\" or \"_\"."
(aset table c c)
+ ;; Clear out the extra slots so that they will be
+ ;; recomputed from the main (downcase) table.
(set-char-table-extra-slot table 0 nil)
(set-char-table-extra-slot table 1 nil)
(set-char-table-extra-slot table 2 nil)
diff --git a/lisp/emacs-lisp/lisp.el b/lisp/emacs-lisp/lisp.el
index 69938255112..d19eace5824 100644
--- a/lisp/emacs-lisp/lisp.el
+++ b/lisp/emacs-lisp/lisp.el
@@ -140,18 +140,18 @@ A negative argument means move backward but still to a less deep spot."
(setq arg (- arg inc)))))
(defun kill-sexp (&optional arg)
- "Kill the sexp (balanced expression) following the cursor.
-With ARG, kill that many sexps after the cursor.
-Negative arg -N means kill N sexps before the cursor."
+ "Kill the sexp (balanced expression) following point.
+With ARG, kill that many sexps after point.
+Negative arg -N means kill N sexps before point."
(interactive "p")
(let ((opoint (point)))
(forward-sexp (or arg 1))
(kill-region opoint (point))))
(defun backward-kill-sexp (&optional arg)
- "Kill the sexp (balanced expression) preceding the cursor.
-With ARG, kill that many sexps before the cursor.
-Negative arg -N means kill N sexps after the cursor."
+ "Kill the sexp (balanced expression) preceding point.
+With ARG, kill that many sexps before point.
+Negative arg -N means kill N sexps after point."
(interactive "p")
(kill-sexp (- (or arg 1))))
diff --git a/lisp/gnus/ChangeLog b/lisp/gnus/ChangeLog
index 4eee8bcbbfc..77a600427e2 100644
--- a/lisp/gnus/ChangeLog
+++ b/lisp/gnus/ChangeLog
@@ -1,3 +1,10 @@
+2005-01-20 Katsumi Yamaoka <yamaoka@jpl.org>
+
+ * mm-decode.el (mm-insert-part): Switch the multibyteness of data
+ which will be inserted according to the multibyteness of a buffer
+ rather than the type of contents. Suggested by ARISAWA Akihiro
+ <ari@mbf.ocn.ne.jp>.
+
2005-01-05 Reiner Steib <Reiner.Steib@gmx.de>
* spam.el (spam-face): New face. Don't use `gnus-splash-face'
diff --git a/lisp/gnus/mm-decode.el b/lisp/gnus/mm-decode.el
index b167ea7d104..569890b8097 100644
--- a/lisp/gnus/mm-decode.el
+++ b/lisp/gnus/mm-decode.el
@@ -1,5 +1,5 @@
;;; mm-decode.el --- Functions for decoding MIME things
-;; Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004
+;; Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
;; Free Software Foundation, Inc.
;; Author: Lars Magne Ingebrigtsen <larsi@gnus.org>
@@ -1032,27 +1032,10 @@ external if displayed external."
(defun mm-insert-part (handle)
"Insert the contents of HANDLE in the current buffer."
- (let ((cur (current-buffer)))
- (save-excursion
- (if (member (mm-handle-media-supertype handle) '("text" "message"))
- (with-temp-buffer
- (insert-buffer-substring (mm-handle-buffer handle))
- (prog1
- (mm-decode-content-transfer-encoding
- (mm-handle-encoding handle)
- (mm-handle-media-type handle))
- (let ((temp (current-buffer)))
- (set-buffer cur)
- (insert-buffer-substring temp))))
- (mm-with-unibyte-buffer
- (insert-buffer-substring (mm-handle-buffer handle))
- (prog1
- (mm-decode-content-transfer-encoding
- (mm-handle-encoding handle)
- (mm-handle-media-type handle))
- (let ((temp (current-buffer)))
- (set-buffer cur)
- (insert-buffer-substring temp))))))))
+ (save-excursion
+ (insert (if (mm-multibyte-p)
+ (mm-string-as-multibyte (mm-get-part handle))
+ (mm-get-part handle)))))
(defun mm-file-name-delete-whitespace (file-name)
"Remove all whitespace characters from FILE-NAME."
diff --git a/lisp/hilit-chg.el b/lisp/hilit-chg.el
index 6c2c7e26ea0..f670079e7d7 100644
--- a/lisp/hilit-chg.el
+++ b/lisp/hilit-chg.el
@@ -1,6 +1,6 @@
;;; hilit-chg.el --- minor mode displaying buffer changes with special face
-;; Copyright (C) 1998, 2000 Free Software Foundation, Inc.
+;; Copyright (C) 1998, 2000, 2005 Free Software Foundation, Inc.
;; Author: Richard Sharman <rsharman@pobox.com>
;; Keywords: faces
@@ -392,8 +392,6 @@ Otherwise, this list will be constructed when needed from
;; These shouldn't be changed!
-;; Autoload for the benefit of `make-mode-line-mouse-sensitive'.
-;;;###autoload
(defvar highlight-changes-mode nil)
(defvar hilit-chg-list nil)
(defvar hilit-chg-string " ??")
@@ -1163,5 +1161,5 @@ from `global-highlight-changes' when turning on global Highlight Changes mode."
(provide 'hilit-chg)
-;;; arch-tag: de00301d-5bad-44da-aa82-e0e010b0c463
+;; arch-tag: de00301d-5bad-44da-aa82-e0e010b0c463
;;; hilit-chg.el ends here
diff --git a/lisp/net/eudc.el b/lisp/net/eudc.el
index bcdd1d195bf..2e6b1625146 100644
--- a/lisp/net/eudc.el
+++ b/lisp/net/eudc.el
@@ -1214,7 +1214,7 @@ queries the server for the existing fields and displays a corresponding form."
;;; Load the options file
(if (and (not noninteractive)
(and (locate-library eudc-options-file)
- (message "")) ; Remove modeline message
+ (progn (message "") t)) ; Remove modeline message
(not (featurep 'eudc-options-file)))
(load eudc-options-file))
diff --git a/lisp/net/tramp-smb.el b/lisp/net/tramp-smb.el
index d0a7cf7b65f..6fa0433a574 100644
--- a/lisp/net/tramp-smb.el
+++ b/lisp/net/tramp-smb.el
@@ -172,7 +172,7 @@ This variable is local to each buffer.")
(set-file-modes . tramp-smb-not-handled)
(set-visited-file-modtime . tramp-smb-not-handled)
(shell-command . tramp-smb-not-handled)
- ;; `substitute-in-file-name' performed by default handler
+ (substitute-in-file-name . tramp-smb-handle-substitute-in-file-name)
(unhandled-file-name-directory . tramp-handle-unhandled-file-name-directory)
(vc-registered . tramp-smb-not-handled)
(verify-visited-file-modtime . tramp-smb-not-handled)
@@ -617,6 +617,13 @@ WILDCARD and FULL-DIRECTORY-P are not handled."
(delete-file filename))
+(defun tramp-smb-handle-substitute-in-file-name (filename)
+ "Like `handle-substitute-in-file-name' for tramp files.
+Catches errors for shares like \"C$/\", which are common in Microsoft Windows."
+ (condition-case nil
+ (tramp-run-real-handler 'substitute-in-file-name (list filename))
+ (error filename)))
+
(defun tramp-smb-handle-write-region
(start end filename &optional append visit lockname confirm)
"Like `write-region' for tramp files."
@@ -1084,54 +1091,6 @@ Return the difference in the format of a time value."
(- (+ (if borrow 65536 0) (cadr t1)) (cadr t2)))))
-;; `PC-do-completion' touches the returning "$$" by `substitute-in-file-name'.
-;; Must be corrected.
-
-(defadvice PC-do-completion (around tramp-smb-advice-PC-do-completion)
- "Changes \"$\" back to \"$$\" in minibuffer."
- (if (funcall PC-completion-as-file-name-predicate)
-
- (progn
- ;; Substitute file names
- (let* ((beg (or (and (functionp 'minibuffer-prompt-end) ; Emacs 21
- (funcall 'minibuffer-prompt-end))
- (point-min)))
- (end (point-max))
- (str (substitute-in-file-name (buffer-substring beg end))))
- (delete-region beg end)
- (insert str)
- (ad-set-arg 2 (point)))
-
- ;; Do `PC-do-completion' without substitution
- (let* (save)
- (fset 'save (symbol-function 'substitute-in-file-name))
- (unwind-protect
- (progn
- (fset 'substitute-in-file-name (symbol-function 'identity))
- ad-do-it)
- (fset 'substitute-in-file-name (symbol-function 'save))))
-
- ;; Expand "$"
- (let* ((beg (or (and (functionp 'minibuffer-prompt-end) ; Emacs 21
- (funcall 'minibuffer-prompt-end))
- (point-min)))
- (end (point-max))
- (str (buffer-substring beg end)))
- (delete-region beg end)
- (insert (if (string-match "\\(\\$\\)\\(/\\|$\\)" str)
- (replace-match "$$" nil nil str 1)
- str))))
-
- ;; No file names. Behave unchanged.
- ad-do-it))
-
-;; Activate advice. Recent Emacsen don't need that.
-(when (functionp 'PC-do-completion)
- (condition-case nil
- (substitute-in-file-name "C$/")
- (error
- (ad-activate 'PC-do-completion))))
-
(provide 'tramp-smb)
;;; TODO:
diff --git a/lisp/net/tramp-util.el b/lisp/net/tramp-util.el
index 2d828d27c51..1cd7f14dcd6 100644
--- a/lisp/net/tramp-util.el
+++ b/lisp/net/tramp-util.el
@@ -1,9 +1,9 @@
;;; -*- coding: iso-2022-7bit; -*-
;;; tramp-util.el --- Misc utility functions to use with Tramp
-;; Copyright (C) 2001 Free Software Foundation, Inc.
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
-;; Author: Kai Gro,A_(Bjohann <Kai.Grossjohann@CS.Uni-Dortmund.DE>
+;; Author: kai.grossjohann@gmx.net
;; Keywords: comm, extensions, processes
;; This file is free software; you can redistribute it and/or modify
@@ -32,6 +32,60 @@
(require 'compile)
(require 'tramp)
+;; Define a Tramp minor mode. It's intention is to redefine some keys for Tramp
+;; specific functions, like compilation.
+;; The key remapping works since Emacs 21.4 only. Unknown for XEmacs.
+
+(when (fboundp 'define-minor-mode)
+
+ (defvar tramp-minor-mode-map (make-sparse-keymap)
+ "Keymap for Tramp minor mode.")
+
+ (define-minor-mode tramp-minor-mode "Tramp minor mode for utility functions."
+ :group 'tramp
+ :global nil
+ :init-value nil
+ :lighter " Tramp"
+ :keymap tramp-minor-mode-map
+ (setq tramp-minor-mode
+ (and tramp-minor-mode (tramp-tramp-file-p default-directory))))
+
+ (add-hook 'find-file-hooks 'tramp-minor-mode t)
+ (add-hook 'dired-mode-hook 'tramp-minor-mode t)
+
+ (defun tramp-remap-command (old-command new-command)
+ "Replaces bindings of OLD-COMMAND by NEW-COMMAND.
+If remapping functionality for keymaps is defined, this happens for all
+bindings. Otherwise, only bindings active during invocation are taken
+into account. XEmacs menubar bindings are not changed by this."
+ (if (functionp 'command-remapping)
+ ;; Emacs 21.4
+ (eval
+ `(define-key tramp-minor-mode-map [remap ,old-command] new-command))
+ ;; previous Emacs 21 versions.
+ (mapcar
+ '(lambda (x)
+ (define-key tramp-minor-mode-map x new-command))
+ (where-is-internal old-command))))
+
+ (tramp-remap-command 'compile 'tramp-compile)
+ (tramp-remap-command 'recompile 'tramp-recompile)
+
+ ;; XEmacs has an own mimic for menu entries
+ (when (fboundp 'add-menu-button)
+ (funcall 'add-menu-button
+ '("Tools" "Compile")
+ ["Compile..."
+ (command-execute (if tramp-minor-mode 'tramp-compile 'compile))
+ :active (fboundp 'compile)])
+ (funcall 'add-menu-button
+ '("Tools" "Compile")
+ ["Repeat Compilation"
+ (command-execute (if tramp-minor-mode 'tramp-recompile 'recompile))
+ :active (fboundp 'compile)])))
+
+;; Utility functions.
+
(defun tramp-compile (command)
"Compile on remote host."
(interactive
@@ -49,6 +103,16 @@
(setq default-directory d)))
(tramp-handle-shell-command command (get-buffer "*Compilation*"))
(pop-to-buffer (get-buffer "*Compilation*"))
+ (tramp-minor-mode 1)
+ (compilation-minor-mode 1))
+
+(defun tramp-recompile ()
+ "Re-compile on remote host."
+ (interactive)
+ (save-some-buffers (not compilation-ask-about-save) nil)
+ (tramp-handle-shell-command compile-command (get-buffer "*Compilation*"))
+ (pop-to-buffer (get-buffer "*Compilation*"))
+ (tramp-minor-mode 1)
(compilation-minor-mode 1))
(provide 'tramp-util)
diff --git a/lisp/net/tramp-vc.el b/lisp/net/tramp-vc.el
index 3cc54eda650..c2a9ae737df 100644
--- a/lisp/net/tramp-vc.el
+++ b/lisp/net/tramp-vc.el
@@ -130,7 +130,8 @@ See `vc-do-command' for more information."
(save-excursion
(save-window-excursion
;; Actually execute remote command
- (shell-command
+ ;; `shell-command' cannot be used; it isn't magic in XEmacs.
+ (tramp-handle-shell-command
(mapconcat 'tramp-shell-quote-argument
(cons command squeezed) " ") t)
;;(tramp-wait-for-output)
@@ -190,7 +191,8 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
(let ((w32-quote-process-args t))
(when (eq okstatus 'async)
(message "Tramp doesn't do async commands, running synchronously."))
- (setq status (shell-command
+ ;; `shell-command' cannot be used; it isn't magic in XEmacs.
+ (setq status (tramp-handle-shell-command
(mapconcat 'tramp-shell-quote-argument
(cons command squeezed) " ") t))
(when (or (not (integerp status))
@@ -285,7 +287,8 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
(save-excursion
(save-window-excursion
;; Actually execute remote command
- (shell-command
+ ;; `shell-command' cannot be used; it isn't magic in XEmacs.
+ (tramp-handle-shell-command
(mapconcat 'tramp-shell-quote-argument
(append (list command) args (list localname)) " ")
(get-buffer-create"*vc-info*"))
diff --git a/lisp/net/tramp.el b/lisp/net/tramp.el
index 34572e98674..90bc30744c7 100644
--- a/lisp/net/tramp.el
+++ b/lisp/net/tramp.el
@@ -1,7 +1,7 @@
;;; -*- mode: Emacs-Lisp; coding: iso-2022-7bit; -*-
;;; tramp.el --- Transparent Remote Access, Multiple Protocol
-;; Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+;; Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
;; Author: kai.grossjohann@gmx.net
;; Keywords: comm, processes
@@ -912,6 +912,15 @@ The answer will be provided by `tramp-action-terminal', which see."
:group 'tramp
:type 'regexp)
+(defcustom tramp-operation-not-permitted-regexp
+ (concat "\\(" "preserving times.*" "\\|" "set mode" "\\)" ":\\s-*"
+ (regexp-opt '("Operation not permitted") t))
+ "Regular expression matching keep-date problems in (s)cp operations.
+Copying has been performed successfully already, so this message can
+be ignored safely."
+ :group 'tramp
+ :type 'regexp)
+
(defcustom tramp-process-alive-regexp
""
"Regular expression indicating a process has finished.
@@ -2500,7 +2509,7 @@ if the remote host can't provide the modtime."
(fa2 (file-attributes file2)))
(if (and (not (equal (nth 5 fa1) '(0 0)))
(not (equal (nth 5 fa2) '(0 0))))
- (< 0 (tramp-time-diff (nth 5 fa1) (nth 5 fa2)))
+ (> 0 (tramp-time-diff (nth 5 fa2) (nth 5 fa1)))
;; If one of them is the dont-know value, then we can
;; still try to run a shell command on the remote host.
;; However, this only works if both files are Tramp
@@ -2822,10 +2831,8 @@ if the remote host can't provide the modtime."
;; At least one file a tramp file?
(if (or (tramp-tramp-file-p filename)
(tramp-tramp-file-p newname))
- (let ((modes (file-modes filename)))
- (tramp-do-copy-or-rename-file
- 'copy filename newname ok-if-already-exists keep-date)
- (set-file-modes newname modes))
+ (tramp-do-copy-or-rename-file
+ 'copy filename newname ok-if-already-exists keep-date)
(tramp-run-real-handler
'copy-file
(list filename newname ok-if-already-exists keep-date))))
@@ -2973,8 +2980,9 @@ KEEP-DATE is non-nil if NEWNAME should have the same timestamp as FILENAME."
(when keep-date
(when (and (not (null modtime))
(not (equal modtime '(0 0))))
- (tramp-touch newname modtime))
- (set-file-modes newname (file-modes filename))))
+ (tramp-touch newname modtime)))
+ ;; Set the mode.
+ (set-file-modes newname (file-modes filename)))
;; If the operation was `rename', delete the original file.
(unless (eq op 'copy)
(delete-file filename))))
@@ -2994,15 +3002,34 @@ If KEEP-DATE is non-nil, preserve the time stamp when copying."
"Unknown operation `%s', must be `copy' or `rename'"
op)))))
(save-excursion
- (tramp-barf-unless-okay
+ (tramp-send-command
multi-method method user host
(format "%s %s %s"
cmd
(tramp-shell-quote-argument localname1)
- (tramp-shell-quote-argument localname2))
- nil 'file-error
- "Copying directly failed, see buffer `%s' for details."
- (buffer-name)))))
+ (tramp-shell-quote-argument localname2)))
+ (tramp-wait-for-output)
+ (goto-char (point-min))
+ (unless
+ (or
+ (and (eq op 'copy) keep-date
+ ;; Mask cp -f error.
+ (re-search-forward tramp-operation-not-permitted-regexp nil t))
+ (zerop (tramp-send-command-and-check
+ multi-method method user host nil nil)))
+ (pop-to-buffer (current-buffer))
+ (signal 'file-error
+ (format "Copying directly failed, see buffer `%s' for details."
+ (buffer-name)))))
+ ;; Set the mode.
+ ;; CCC: Maybe `chmod --reference=localname1 localname2' could be used
+ ;; where available?
+ (unless (or (eq op 'rename) keep-date)
+ (set-file-modes
+ (tramp-make-tramp-file-name multi-method method user host localname2)
+ (file-modes
+ (tramp-make-tramp-file-name
+ multi-method method user host localname1))))))
(defun tramp-do-copy-or-rename-file-out-of-band (op filename newname keep-date)
"Invoke rcp program to copy.
@@ -3122,7 +3149,11 @@ be a local filename. The method used must be an out-of-band method."
tramp-actions-copy-out-of-band))
(kill-buffer trampbuf)
(tramp-message
- 5 "Transferring %s to file %s...done" filename newname))
+ 5 "Transferring %s to file %s...done" filename newname)
+
+ ;; Set the mode.
+ (unless keep-date
+ (set-file-modes newname (file-modes filename))))
;; If the operation was `rename', delete the original file.
(unless (eq op 'copy)
@@ -4074,7 +4105,9 @@ ARGS are the arguments OPERATION has been called with."
(if (bufferp (nth 0 args)) (nth 0 args) (current-buffer))))
; COMMAND
((member operation
- (list 'dired-call-process 'shell-command
+ (list 'dired-call-process-command
+ ; Emacs only
+ 'shell
; Post Emacs 21.3 only
'process-file
; XEmacs only
@@ -4908,7 +4941,10 @@ USER the array of user names, HOST the array of host names."
(defun tramp-get-buffer (multi-method method user host)
"Get the connection buffer to be used for USER at HOST using METHOD."
- (get-buffer-create (tramp-buffer-name multi-method method user host)))
+ (with-current-buffer
+ (get-buffer-create (tramp-buffer-name multi-method method user host))
+ (setq buffer-undo-list t)
+ (current-buffer)))
(defun tramp-debug-buffer-name (multi-method method user host)
"A name for the debug buffer for USER at HOST using METHOD."
@@ -4922,7 +4958,11 @@ USER the array of user names, HOST the array of host names."
(defun tramp-get-debug-buffer (multi-method method user host)
"Get the debug buffer for USER at HOST using METHOD."
- (get-buffer-create (tramp-debug-buffer-name multi-method method user host)))
+ (with-current-buffer
+ (get-buffer-create
+ (tramp-debug-buffer-name multi-method method user host))
+ (setq buffer-undo-list t)
+ (current-buffer)))
(defun tramp-find-executable (multi-method method user host
progname dirlist ignore-tilde)
@@ -5214,8 +5254,16 @@ The terminal type can be configured with `tramp-terminal-type'."
((or (and (memq (process-status p) '(stop exit))
(not (zerop (process-exit-status p))))
(memq (process-status p) '(signal)))
- (tramp-message 9 "Process has died.")
- (throw 'tramp-action 'process-died))
+ ;; `scp' could have copied correctly, but set modes could have failed.
+ ;; This can be ignored.
+ (goto-char (point-min))
+ (if (re-search-forward tramp-operation-not-permitted-regexp nil t)
+ (progn
+ (tramp-message 10 "'set mode' error ignored.")
+ (tramp-message 9 "Process has finished.")
+ (throw 'tramp-action 'ok))
+ (tramp-message 9 "Process has died.")
+ (throw 'tramp-action 'process-died)))
(t nil)))
;; The following functions are specifically for multi connections.
@@ -6336,7 +6384,7 @@ Sends COMMAND, then waits 30 seconds for shell prompt."
(save-excursion
(goto-char start-point)
(when (looking-at (regexp-quote tramp-last-cmd))
- (delete-region (point) (forward-line 1)))))
+ (delete-region (point) (progn (forward-line 1) (point))))))
;; Add output to debug buffer if appropriate.
(when tramp-debug-buffer
(append-to-buffer
diff --git a/lisp/net/trampver.el b/lisp/net/trampver.el
index 866d6e5647d..a4aced24257 100644
--- a/lisp/net/trampver.el
+++ b/lisp/net/trampver.el
@@ -30,7 +30,7 @@
;; are auto-frobbed from configure.ac, so you should edit that file and run
;; "autoconf && ./configure" to change them.
-(defconst tramp-version "2.0.46"
+(defconst tramp-version "2.0.47"
"This version of Tramp.")
(defconst tramp-bug-report-address "tramp-devel@mail.freesoftware.fsf.org"
diff --git a/lisp/pcomplete.el b/lisp/pcomplete.el
index f4b796dd1a7..b01bef39664 100644
--- a/lisp/pcomplete.el
+++ b/lisp/pcomplete.el
@@ -946,8 +946,10 @@ generate the completions list. This means that the hook
(unless (fboundp 'event-matches-key-specifier-p)
(defalias 'event-matches-key-specifier-p 'eq))
-(unless (fboundp 'read-event)
- (defsubst read-event (&optional prompt)
+(if (fboundp 'read-event)
+ (defsubst pcomplete-read-event (&optional prompt)
+ (read-event prompt))
+ (defsubst pcomplete-read-event (&optional prompt)
(aref (read-key-sequence prompt) 0)))
(unless (fboundp 'event-basic-type)
@@ -969,7 +971,7 @@ Typing SPC flushes the help buffer."
(prog1
(catch 'done
(while (with-current-buffer (get-buffer "*Completions*")
- (setq event (read-event)))
+ (setq event (pcomplete-read-event)))
(cond
((event-matches-key-specifier-p event ? )
(set-window-configuration pcomplete-last-window-config)
diff --git a/lisp/play/decipher.el b/lisp/play/decipher.el
index 7c08856da80..00bcbbf13c5 100644
--- a/lisp/play/decipher.el
+++ b/lisp/play/decipher.el
@@ -305,7 +305,8 @@ The most useful commands are:
(setq case-fold-search nil)) ;Case is significant when searching
(use-local-map decipher-mode-map)
(set-syntax-table decipher-mode-syntax-table)
- (decipher-read-alphabet)
+ (unless (= (point-min) (point-max))
+ (decipher-read-alphabet))
(set (make-local-variable 'font-lock-defaults)
'(decipher-font-lock-keywords t))
;; Make the buffer writable when we exit Decipher mode:
diff --git a/lisp/progmodes/grep.el b/lisp/progmodes/grep.el
index 04fcae78ea6..a3b1ab3abdd 100644
--- a/lisp/progmodes/grep.el
+++ b/lisp/progmodes/grep.el
@@ -527,7 +527,8 @@ This command uses a special history list for its arguments, so you can
easily repeat a find command."
(interactive
(progn
- (unless grep-find-command
+ (unless (and grep-command
+ (or (not grep-use-null-device) (eq grep-use-null-device t)))
(grep-compute-defaults))
(if grep-find-command
(list (read-from-minibuffer "Run find (like this): "
@@ -541,6 +542,9 @@ easily repeat a find command."
(let ((null-device nil)) ; see grep
(grep command-args))))
+;;;###autoload
+(defalias 'find-grep 'grep-find)
+
(defun grep-expand-command-macros (command &optional regexp files dir excl case-fold)
"Patch grep COMMAND replacing <D>, etc."
(setq command
diff --git a/lisp/progmodes/sh-script.el b/lisp/progmodes/sh-script.el
index a1e868a3926..d08af6e8531 100644
--- a/lisp/progmodes/sh-script.el
+++ b/lisp/progmodes/sh-script.el
@@ -1,6 +1,6 @@
;;; sh-script.el --- shell-script editing commands for Emacs
-;; Copyright (C) 1993, 94, 95, 96, 97, 1999, 2001, 03, 2004
+;; Copyright (C) 1993, 1994, 1995, 1996, 1997, 1999, 2001, 2003, 2004, 2005
;; Free Software Foundation, Inc.
;; Author: Daniel Pfeiffer <occitan@esperanto.org>
@@ -838,7 +838,7 @@ See `sh-feature'.")
(defconst sh-st-symbol (string-to-syntax "_"))
(defconst sh-here-doc-syntax (string-to-syntax "|")) ;; generic string
-(defconst sh-here-doc-open-re "<<-?\\s-*\\\\?\\(\\(?:['\"][^'\"]+['\"]\\|\\sw\\|\\s_\\)+\\).*\\(\n\\)")
+(defconst sh-here-doc-open-re "<<-?\\s-*\\\\?\\(\\(?:['\"][^'\"]+['\"]\\|\\sw\\)+\\).*\\(\n\\)")
(defvar sh-here-doc-markers nil)
(make-variable-buffer-local 'sh-here-doc-markers)
@@ -3631,5 +3631,5 @@ shell command and conveniently use this command."
(provide 'sh-script)
-;;; arch-tag: eccd8b72-f337-4fc2-ae86-18155a69d937
+;; arch-tag: eccd8b72-f337-4fc2-ae86-18155a69d937
;;; sh-script.el ends here
diff --git a/lisp/ses.el b/lisp/ses.el
index 2a952aab286..49d4f49d94a 100644
--- a/lisp/ses.el
+++ b/lisp/ses.el
@@ -405,26 +405,6 @@ for safety. This is a macro to prevent propagate-on-load viruses."
(setq ses--header-row row)
t)
-(defmacro ses-dotimes-msg (spec msg &rest body)
- "(ses-dotimes-msg (VAR LIMIT) MSG BODY...): Like `dotimes', but
-a message is emitted using MSG every second or so during the loop."
- (let ((msgvar (make-symbol "msg"))
- (limitvar (make-symbol "limit"))
- (var (car spec))
- (limit (cadr spec)))
- `(let ((,limitvar ,limit)
- (,msgvar ,msg))
- (setq ses-start-time (float-time))
- (message ,msgvar)
- (setq ,msgvar (concat ,msgvar " (%d%%)"))
- (dotimes (,var ,limitvar)
- (ses-time-check ,msgvar '(/ (* ,var 100) ,limitvar))
- ,@body)
- (message nil))))
-
-(put 'ses-dotimes-msg 'lisp-indent-function 2)
-(def-edebug-spec ses-dotimes-msg ((symbolp form) form body))
-
(defmacro ses-dorange (curcell &rest body)
"Execute BODY repeatedly, with the variables `row' and `col' set to each
cell in the range specified by CURCELL. The range is available in the
@@ -1218,7 +1198,8 @@ the rectangle (MINROW,MINCOL)..(NUMROWS,NUMCOLS) by adding ROWINCR and COLINCR
to each symbol."
(let (reform)
(let (mycell newval)
- (ses-dotimes-msg (row ses--numrows) "Relocating formulas..."
+ (dotimes-with-progress-reporter
+ (row ses--numrows) "Relocating formulas..."
(dotimes (col ses--numcols)
(setq ses-relocate-return nil
mycell (ses-get-cell row col)
@@ -1246,7 +1227,8 @@ to each symbol."
(cond
((and (<= rowincr 0) (<= colincr 0))
;;Deletion of rows and/or columns
- (ses-dotimes-msg (row (- ses--numrows minrow)) "Relocating variables..."
+ (dotimes-with-progress-reporter
+ (row (- ses--numrows minrow)) "Relocating variables..."
(setq myrow (+ row minrow))
(dotimes (col (- ses--numcols mincol))
(setq mycol (+ col mincol)
@@ -1262,7 +1244,8 @@ to each symbol."
(let ((disty (1- ses--numrows))
(distx (1- ses--numcols))
myrow mycol)
- (ses-dotimes-msg (row (- ses--numrows minrow)) "Relocating variables..."
+ (dotimes-with-progress-reporter
+ (row (- ses--numrows minrow)) "Relocating variables..."
(setq myrow (- disty row))
(dotimes (col (- ses--numcols mincol))
(setq mycol (- distx col)
@@ -1475,7 +1458,7 @@ Narrows the buffer to show only the print area. Gives it `read-only' and
(put-text-property (point-min) (1+ (point-min)) 'front-sticky t)
;;Create intangible properties, which also indicate which cell the text
;;came from.
- (ses-dotimes-msg (row ses--numrows) "Finding cells..."
+ (dotimes-with-progress-reporter (row ses--numrows) "Finding cells..."
(dotimes (col ses--numcols)
(setq pos end
sym (ses-cell-symbol row col))
@@ -1724,7 +1707,7 @@ print area if NONARROW is nil."
;;find the data area when inserting or deleting *skip* values for cells
(dotimes (row ses--numrows)
(insert-and-inherit ses--blank-line))
- (ses-dotimes-msg (row ses--numrows) "Reprinting..."
+ (dotimes-with-progress-reporter (row ses--numrows) "Reprinting..."
(if (eq (ses-cell-value row 0) '*skip*)
;;Column deletion left a dangling skip
(ses-set-cell row 0 'value nil))
@@ -1809,11 +1792,13 @@ cells."
;;Reconstruct reference lists.
(let (x yrow ycol)
;;Delete old reference lists
- (ses-dotimes-msg (row ses--numrows) "Deleting references..."
+ (dotimes-with-progress-reporter
+ (row ses--numrows) "Deleting references..."
(dotimes (col ses--numcols)
(ses-set-cell row col 'references nil)))
;;Create new reference lists
- (ses-dotimes-msg (row ses--numrows) "Computing references..."
+ (dotimes-with-progress-reporter
+ (row ses--numrows) "Computing references..."
(dotimes (col ses--numcols)
(dolist (ref (ses-formula-references (ses-cell-formula row col)))
(setq x (ses-sym-rowcol ref)
@@ -2073,7 +2058,7 @@ before current one."
(ses-set-parameter 'ses--numrows (+ ses--numrows count))
;;Insert each row
(ses-goto-print row 0)
- (ses-dotimes-msg (x count) "Inserting row..."
+ (dotimes-with-progress-reporter (x count) "Inserting row..."
;;Create a row of empty cells. The `symbol' fields will be set by
;;the call to ses-relocate-all.
(setq newrow (make-vector ses--numcols nil))
@@ -2162,7 +2147,7 @@ If COL is specified, the new column(s) get the specified WIDTH and PRINTER
(ses-create-cell-variable-range 0 (1- ses--numrows)
ses--numcols (+ ses--numcols count -1))
;;Insert each column.
- (ses-dotimes-msg (x count) "Inserting column..."
+ (dotimes-with-progress-reporter (x count) "Inserting column..."
;;Create a column of empty cells. The `symbol' fields will be set by
;;the call to ses-relocate-all.
(ses-adjust-print-width col (1+ width))
@@ -2220,7 +2205,7 @@ from the current one."
(ses-begin-change)
(ses-set-parameter 'ses--numcols (- ses--numcols count))
(ses-adjust-print-width col (- width))
- (ses-dotimes-msg (row ses--numrows) "Deleting column..."
+ (dotimes-with-progress-reporter (row ses--numrows) "Deleting column..."
;;Delete lines from cell data area
(ses-goto-data row col)
(ses-delete-line count)
@@ -2469,7 +2454,7 @@ formulas are to be inserted without relocation."
(colincr (- (cdr rowcol) (cdr first)))
(pos 0)
myrow mycol x)
- (ses-dotimes-msg (row needrows) "Yanking..."
+ (dotimes-with-progress-reporter (row needrows) "Yanking..."
(setq myrow (+ row (car rowcol)))
(dotimes (col needcols)
(setq mycol (+ col (cdr rowcol))
diff --git a/lisp/simple.el b/lisp/simple.el
index 77bdb47e250..c54c67ea8ac 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -1,7 +1,7 @@
;;; simple.el --- basic editing commands for Emacs
;; Copyright (C) 1985, 1986, 1987, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
-;; 2000, 2001, 2002, 2003, 2004
+;; 2000, 2001, 2002, 2003, 2004, 2005
;; Free Software Foundation, Inc.
;; Maintainer: FSF
@@ -647,13 +647,13 @@ If BACKWARD-ONLY is non-nil, only delete spaces before point."
(skip-chars-backward " \t")
(constrain-to-field nil orig-pos)))))
-(defun just-one-space (n)
+(defun just-one-space (&optional n)
"Delete all spaces and tabs around point, leaving one space (or N spaces)."
(interactive "*p")
(let ((orig-pos (point)))
(skip-chars-backward " \t")
(constrain-to-field nil orig-pos)
- (dotimes (i n)
+ (dotimes (i (or n 1))
(if (= (following-char) ?\ )
(forward-char 1)
(insert ?\ )))
@@ -3179,10 +3179,31 @@ Outline mode sets this."
(or (memq prop buffer-invisibility-spec)
(assq prop buffer-invisibility-spec)))))
+;; Perform vertical scrolling of tall images if necessary.
+(defun line-move (arg &optional noerror to-end)
+ (if auto-window-vscroll
+ (let ((forward (> arg 0))
+ (pvis (pos-visible-in-window-p (window-start) nil t)))
+ (if (and pvis (null (nth 2 pvis))
+ (> (nth (if forward 4 3) pvis) 0))
+ (set-window-vscroll nil
+ (if forward
+ (+ (window-vscroll nil t)
+ (min (nth 4 pvis)
+ (* (frame-char-height) arg)))
+ (max 0
+ (- (window-vscroll nil t)
+ (min (nth 3 pvis)
+ (* (frame-char-height) (- arg))))))
+ t)
+ (set-window-vscroll nil 0)
+ (line-move-1 arg noerror to-end)))
+ (line-move-1 arg noerror to-end)))
+
;; This is the guts of next-line and previous-line.
;; Arg says how many lines to move.
;; The value is t if we can move the specified number of lines.
-(defun line-move (arg &optional noerror to-end)
+(defun line-move-1 (arg &optional noerror to-end)
;; Don't run any point-motion hooks, and disregard intangibility,
;; for intermediate positions.
(let ((inhibit-point-motion-hooks t)
@@ -4001,7 +4022,7 @@ when it is off screen)."
(setq matching-paren
(let ((syntax (syntax-after blinkpos)))
(and (consp syntax)
- (eq (car syntax) 4)
+ (eq (logand (car syntax) 255) 4)
(cdr syntax)))
mismatch
(or (null matching-paren)
diff --git a/lisp/subr.el b/lisp/subr.el
index 36931acf628..2a5154b533e 100644
--- a/lisp/subr.el
+++ b/lisp/subr.el
@@ -1,7 +1,7 @@
;;; subr.el --- basic lisp subroutines for Emacs
;; Copyright (C) 1985, 1986, 1992, 1994, 1995, 1999, 2000, 2001, 2002, 2003,
-;; 2004 Free Software Foundation, Inc.
+;; 2004, 2005 Free Software Foundation, Inc.
;; Maintainer: FSF
;; Keywords: internal
@@ -2711,7 +2711,7 @@ you call it."
(defun make-progress-reporter (message min-value max-value
&optional current-value
min-change min-time)
- "Return progress reporter object usage with `progress-reporter-update'.
+ "Return progress reporter object to be used with `progress-reporter-update'.
MESSAGE is shown in the echo area. When at least 1% of operation
is complete, the exact percentage will be appended to the
@@ -2800,5 +2800,32 @@ change the displayed message."
"Print reporter's message followed by word \"done\" in echo area."
(message "%sdone" (aref (cdr reporter) 3)))
+(defmacro dotimes-with-progress-reporter (spec message &rest body)
+ "Loop a certain number of times and report progress in the echo area.
+Evaluate BODY with VAR bound to successive integers running from
+0, inclusive, to COUNT, exclusive. Then evaluate RESULT to get
+the return value (nil if RESULT is omitted).
+
+At each iteration MESSAGE followed by progress percentage is
+printed in the echo area. After the loop is finished, MESSAGE
+followed by word \"done\" is printed. This macro is a
+convenience wrapper around `make-progress-reporter' and friends.
+
+\(fn (VAR COUNT [RESULT]) MESSAGE BODY...)"
+ (declare (indent 2) (debug ((symbolp form &optional form) form body)))
+ (let ((temp (make-symbol "--dotimes-temp--"))
+ (temp2 (make-symbol "--dotimes-temp2--"))
+ (start 0)
+ (end (nth 1 spec)))
+ `(let ((,temp ,end)
+ (,(car spec) ,start)
+ (,temp2 (make-progress-reporter ,message ,start ,end)))
+ (while (< ,(car spec) ,temp)
+ ,@body
+ (progress-reporter-update ,temp2
+ (setq ,(car spec) (1+ ,(car spec)))))
+ (progress-reporter-done ,temp2)
+ nil ,@(cdr (cdr spec)))))
+
;; arch-tag: f7e0e6e5-70aa-4897-ae72-7a3511ec40bc
;;; subr.el ends here
diff --git a/lisp/term/mac-win.el b/lisp/term/mac-win.el
index 869a79e2966..88350151613 100644
--- a/lisp/term/mac-win.el
+++ b/lisp/term/mac-win.el
@@ -1295,10 +1295,9 @@ Switch to a buffer editing the last file dropped."
(if (string= default-directory "/")
(cd "~"))
-;; Tell Emacs to use pipes instead of pty's for processes because the
-;; latter sometimes lose characters. Pty support is compiled in since
-;; ange-ftp will not work without it.
-(setq process-connection-type nil)
+;; Darwin 6- pty breakage is now controlled from the C code so that
+;; it applies to all builds on darwin. See s/darwin.h PTY_ITERATION.
+;; (setq process-connection-type t)
;; Assume that fonts are always scalable on the Mac. This sometimes
;; results in characters with jagged edges. However, without it,
diff --git a/lisp/textmodes/ispell.el b/lisp/textmodes/ispell.el
index 4565d369371..13eda06c892 100644
--- a/lisp/textmodes/ispell.el
+++ b/lisp/textmodes/ispell.el
@@ -2764,6 +2764,15 @@ Point is placed at end of skipped region."
string))
+(defun ispell-looking-at (string)
+ (let ((coding (ispell-get-coding-system))
+ (len (length string)))
+ (and (<= (+ (point) len) (point-max))
+ (equal (encode-coding-string string coding)
+ (encode-coding-string (buffer-substring-no-properties
+ (point) (+ (point) len))
+ coding)))))
+
;;; Avoid error messages when compiling for these dynamic variables.
(eval-when-compile
(defvar start)
@@ -2812,12 +2821,7 @@ Returns the sum shift due to changes in word replacements."
;; Alignment cannot be tracked and this error will occur when
;; `query-replace' makes multiple corrections on the starting line.
- (if (/= (+ word-len (point))
- (progn
- ;; NB: Search can fail with Mule coding systems that don't
- ;; display properly. Ignore the error in this case?
- (search-forward (car poss) (+ word-len (point)) t)
- (point)))
+ (or (ispell-looking-at (car poss))
;; This occurs due to filter pipe problems
(error (concat "Ispell misalignment: word "
"`%s' point %d; probably incompatible versions")
diff --git a/lisp/textmodes/org.el b/lisp/textmodes/org.el
index 80ff7637365..1ff21ea1ce0 100644
--- a/lisp/textmodes/org.el
+++ b/lisp/textmodes/org.el
@@ -215,8 +215,8 @@
(defvar org-version "3.04"
"The version number of the file org.el.")
-(defun org-version (arg)
- (interactive "P")
+(defun org-version ()
+ (interactive)
(message "Org-mode version %s" org-version))
;; The following two constants are for compatibility with different
diff --git a/lisp/textmodes/tex-mode.el b/lisp/textmodes/tex-mode.el
index 1f9336fef50..ee975c100b7 100644
--- a/lisp/textmodes/tex-mode.el
+++ b/lisp/textmodes/tex-mode.el
@@ -1495,7 +1495,9 @@ Mark is left at original location."
(make-comint
"tex-shell"
(or tex-shell-file-name (getenv "ESHELL") shell-file-name)
- nil)
+ nil
+ ;; Specify an interactive shell, to make sure it prompts.
+ "-i")
(let ((proc (get-process "tex-shell")))
(set-process-sentinel proc 'tex-shell-sentinel)
(set-process-query-on-exit-flag proc nil)
diff --git a/lisp/type-break.el b/lisp/type-break.el
index 3a0b8b5adcc..0585e5bc61d 100644
--- a/lisp/type-break.el
+++ b/lisp/type-break.el
@@ -390,8 +390,9 @@ problems."
(and (interactive-p)
(message "Type Break mode is already enabled")))
(type-break-mode
- (with-current-buffer (find-file-noselect type-break-file-name 'nowarn)
- (setq buffer-save-without-query t))
+ (when type-break-file-name
+ (with-current-buffer (find-file-noselect type-break-file-name 'nowarn)
+ (setq buffer-save-without-query t)))
(or global-mode-string
(setq global-mode-string '("")))
diff --git a/lisp/url/ChangeLog b/lisp/url/ChangeLog
index 19f39265251..6dac2389e71 100644
--- a/lisp/url/ChangeLog
+++ b/lisp/url/ChangeLog
@@ -1,3 +1,8 @@
+2005-01-22 Klaus Straubinger <KSNetz@Arcor.DE> (tiny change)
+
+ * url-http.el (url-http-parse-headers) <302>: Reset url-http-data
+ to nil, like for the 303 response.
+
2005-01-13 Stefan Monnier <monnier@iro.umontreal.ca>
* url.el (url-retrieve-synchronously): Use accept-process-output rather
diff --git a/lisp/url/url-http.el b/lisp/url/url-http.el
index 2608a85963a..3a0fbf6ecd6 100644
--- a/lisp/url/url-http.el
+++ b/lisp/url/url-http.el
@@ -459,7 +459,7 @@ should be shown to the user."
(url-http-debug "Converting `%s' request to `GET' because of REDIRECT(%d)"
url-http-method url-http-response-status)
(setq url-http-method "GET"
- url-request-data nil)))
+ url-http-data nil)))
(303
;; The response to the request can be found under a different
;; URI and SHOULD be retrieved using a GET method on that
diff --git a/lisp/window.el b/lisp/window.el
index 5ec752f3f23..5768436eaae 100644
--- a/lisp/window.el
+++ b/lisp/window.el
@@ -1,6 +1,6 @@
;;; window.el --- GNU Emacs window commands aside from those written in C
-;; Copyright (C) 1985, 1989, 1992, 1993, 1994, 2000, 2001, 2002, 2004
+;; Copyright (C) 1985, 1989, 1992, 1993, 1994, 2000, 2001, 2002, 2004, 2005
;; Free Software Foundation, Inc.
;; Maintainer: FSF
@@ -631,6 +631,12 @@ and the buffer that is killed or buried is the one in that window."
(interactive "e")
(let ((window (posn-window (event-start event))))
(if (and (window-live-p window)
+ ;; Don't switch if we're currently in the minibuffer.
+ ;; This tries to work around problems where the minibuffer gets
+ ;; unselected unexpectedly, and where you then have to move
+ ;; your mouse all the way down to the minibuffer to select it.
+ (not (window-minibuffer-p (selected-window)))
+ ;; Don't switch to a minibuffer window unless it's active.
(or (not (window-minibuffer-p window))
(minibuffer-window-active-p window)))
(select-window window))))
@@ -643,5 +649,5 @@ and the buffer that is killed or buried is the one in that window."
(define-key ctl-x-map "+" 'balance-windows)
(define-key ctl-x-4-map "0" 'kill-buffer-and-window)
-;;; arch-tag: b508dfcc-c353-4c37-89fa-e773fe10cea9
+;; arch-tag: b508dfcc-c353-4c37-89fa-e773fe10cea9
;;; window.el ends here
diff --git a/lisp/xt-mouse.el b/lisp/xt-mouse.el
index 5709834ab91..131f95db7d0 100644
--- a/lisp/xt-mouse.el
+++ b/lisp/xt-mouse.el
@@ -1,6 +1,6 @@
;;; xt-mouse.el --- support the mouse when emacs run in an xterm
-;; Copyright (C) 1994, 2000, 2001 Free Software Foundation
+;; Copyright (C) 1994, 2000, 2001, 2005 Free Software Foundation
;; Author: Per Abrahamsen <abraham@dina.kvl.dk>
;; Keywords: mouse, terminals
@@ -24,7 +24,7 @@
;;; Commentary:
-;; Enable mouse support when running inside an xterm or Linux console.
+;; Enable mouse support when running inside an xterm.
;; This is actually useful when you are running X11 locally, but is
;; working on remote machine over a modem line or through a gateway.
@@ -32,15 +32,15 @@
;; It works by translating xterm escape codes into generic emacs mouse
;; events so it should work with any package that uses the mouse.
-;; The xterm mouse escape codes are supposedly also supported by the
-;; Linux console, but I have not been able to verify this.
-
;; You don't have to turn off xterm mode to use the normal xterm mouse
;; functionality, it is still available by holding down the SHIFT key
;; when you press the mouse button.
;;; Todo:
+;; The xterm mouse escape codes are supposedly also supported by the
+;; Linux console, but I have not been able to verify this.
+
;; Support multi-click -- somehow.
;;; Code:
@@ -146,9 +146,9 @@
(setq xterm-mouse-x x
xterm-mouse-y y)
(if w
- (list mouse (posn-at-x-y (- x left) (- y top) w))
+ (list mouse (posn-at-x-y (- x left) (- y top) w t))
(list mouse
- (append (list nil 'menu-bar) (nthcdr 2 (posn-at-x-y x y w)))))))
+ (append (list nil 'menu-bar) (nthcdr 2 (posn-at-x-y x y w t)))))))
;;;###autoload
(define-minor-mode xterm-mouse-mode
diff --git a/lisp/progmodes/gdb-ui.el b/lisp/progmodes/gdb-ui.el
index aef997d2a66..993d440cd0c 100644
--- a/lisp/progmodes/gdb-ui.el
+++ b/lisp/progmodes/gdb-ui.el
@@ -33,24 +33,28 @@
;; Emacs 21 such as the fringe/display margin for breakpoints, and the toolbar
;; (see the GDB Graphical Interface section in the Emacs info manual).
-;; Start the debugger with M-x gdba.
-
-;; This file has evolved from gdba.el from GDB 5.0 written by Tom Lord and Jim
-;; Kingdon and uses GDB's annotation interface. You don't need to know about
-;; annotations to use this mode as a debugger, but if you are interested
-;; developing the mode itself, then see the Annotations section in the GDB
-;; info manual.
+;; By default, M-x gdb will start the debugger. However, if you have customised
+;; gud-gdb-command-name, then start it with M-x gdba.
+
+;; This file has evolved from gdba.el that was included with GDB 5.0 and
+;; written by Tom Lord and Jim Kingdon. It uses GDB's annotation interface.
+;; You don't need to know about annotations to use this mode as a debugger,
+;; but if you are interested developing the mode itself, then see the
+;; Annotations section in the GDB info manual.
;;
;; GDB developers plan to make the annotation interface obsolete. A new
;; interface called GDB/MI (machine interface) has been designed to replace
;; it. Some GDB/MI commands are used in this file through the CLI command
-;; 'interpreter mi <mi-command>'. A file called gdb-mi.el is included in the
-;; GDB repository for future releases (6.2 onwards) that uses GDB/MI as the
-;; primary interface to GDB. It is still under development and is part of a
-;; process to migrate Emacs from annotations to GDB/MI.
+;; 'interpreter mi <mi-command>'. A file called gdb-mi.el is included with
+;; GDB (6.2 onwards) that uses GDB/MI as the primary interface to GDB. It is
+;; still under development and is part of a process to migrate Emacs from
+;; annotations to GDB/MI.
;;
;; Known Bugs:
;;
+;; TODO:
+;; Use tree-widget.el instead of the speedbar for watch-expressions?
+;; Mark breakpoint locations on scroll-bar of source buffer?
;;; Code:
@@ -169,13 +173,13 @@ detailed description of this mode.
(defvar gdb-debug-log nil)
(defcustom gdb-enable-debug-log nil
- "Non-nil means record the process input and output in `gdb-debug-log'."
+ "Non-nil means record the process input and output in `gdb-debug-log'."
:type 'boolean
:group 'gud
:version "21.4")
(defcustom gdb-use-inferior-io-buffer nil
- "Non-nil means display output from the inferior in a separate buffer."
+ "Non-nil means display output from the inferior in a separate buffer."
:type 'boolean
:group 'gud
:version "21.4")
@@ -210,9 +214,13 @@ detailed description of this mode.
"\C-u" "Continue to current line or address.")
(define-key gud-minor-mode-map [left-margin mouse-1]
- 'gdb-mouse-toggle-breakpoint)
+ 'gdb-mouse-set-clear-breakpoint)
(define-key gud-minor-mode-map [left-fringe mouse-1]
+ 'gdb-mouse-set-clear-breakpoint)
+ (define-key gud-minor-mode-map [left-margin mouse-3]
'gdb-mouse-toggle-breakpoint)
+; (define-key gud-minor-mode-map [left-fringe mouse-3]
+; 'gdb-mouse-toggle-breakpoint)
(setq comint-input-sender 'gdb-send)
;;
@@ -281,7 +289,7 @@ detailed description of this mode.
(Info-goto-node "(emacs)GDB Graphical Interface"))
(defconst gdb-var-create-regexp
-"name=\"\\(.*?\\)\",numchild=\"\\(.*?\\)\",type=\"\\(.*?\\)\"")
+ "name=\"\\(.*?\\)\",numchild=\"\\(.*?\\)\",type=\"\\(.*?\\)\"")
(defun gdb-var-create-handler (expr)
(with-current-buffer (gdb-get-create-buffer 'gdb-partial-output-buffer)
@@ -328,7 +336,7 @@ detailed description of this mode.
`(lambda () (gdb-var-list-children-handler ,varnum)))))
(defconst gdb-var-list-children-regexp
-"name=\"\\(.*?\\)\",exp=\"\\(.*?\\)\",numchild=\"\\(.*?\\)\"")
+ "name=\"\\(.*?\\)\",exp=\"\\(.*?\\)\",numchild=\"\\(.*?\\)\"")
(defun gdb-var-list-children-handler (varnum)
(with-current-buffer (gdb-get-create-buffer 'gdb-partial-output-buffer)
@@ -1038,7 +1046,8 @@ happens to be appropriate."
(defvar gdb-cdir nil "Compilation directory.")
-(defconst breakpoint-xpm-data "/* XPM */
+(defconst breakpoint-xpm-data
+ "/* XPM */
static char *magick[] = {
/* columns rows colors chars-per-pixel */
\"10 10 2 1\",
@@ -1059,7 +1068,7 @@ static char *magick[] = {
"XPM data used for breakpoint icon.")
(defconst breakpoint-enabled-pbm-data
-"P1
+ "P1
10 10\",
0 0 0 0 1 1 1 1 0 0 0 0
0 0 0 1 1 1 1 1 1 0 0 0
@@ -1074,7 +1083,7 @@ static char *magick[] = {
"PBM data used for enabled breakpoint icon.")
(defconst breakpoint-disabled-pbm-data
-"P1
+ "P1
10 10\",
0 0 1 0 1 0 1 0 0 0
0 1 0 1 0 1 0 1 0 0
@@ -1116,8 +1125,7 @@ static char *magick[] = {
;;-put breakpoint icons in relevant margins (even those set in the GUD buffer)
(defun gdb-info-breakpoints-custom ()
- (let ((flag))
- ;;
+ (let ((flag) (bptno))
;; remove all breakpoint-icons in source buffers but not assembler buffer
(dolist (buffer (buffer-list))
(with-current-buffer buffer
@@ -1131,12 +1139,13 @@ static char *magick[] = {
(forward-line 1)
(if (looking-at "[^\t].*breakpoint")
(progn
- (looking-at "[0-9]*\\s-*\\S-*\\s-*\\S-*\\s-*\\(.\\)")
- (setq flag (char-after (match-beginning 1)))
+ (looking-at "\\([0-9]+\\)\\s-+\\S-+\\s-+\\S-+\\s-+\\(.\\)")
+ (setq bptno (match-string 1))
+ (setq flag (char-after (match-beginning 2)))
(beginning-of-line)
(if (re-search-forward "in\\s-+\\S-+\\s-+at\\s-+" nil t)
(progn
- (looking-at "\\(\\S-*\\):\\([0-9]+\\)")
+ (looking-at "\\(\\S-+\\):\\([0-9]+\\)")
(let ((line (match-string 2)) (buffer-read-only nil)
(file (match-string 1)))
(add-text-properties (point-at-bol) (point-at-eol)
@@ -1153,12 +1162,12 @@ static char *magick[] = {
;; only want one breakpoint icon at each location
(save-excursion
(goto-line (string-to-number line))
- (gdb-put-breakpoint-icon (eq flag ?y)))))))))
+ (gdb-put-breakpoint-icon (eq flag ?y) bptno))))))))
(end-of-line)))))
(if (gdb-get-buffer 'gdb-assembler-buffer) (gdb-assembler-custom)))
-(defun gdb-mouse-toggle-breakpoint (event)
- "Toggle breakpoint in left fringe/margin with mouse click."
+(defun gdb-mouse-set-clear-breakpoint (event)
+ "Set/clear breakpoint in left fringe/margin with mouse click."
(interactive "e")
(mouse-minibuffer-check event)
(let ((posn (event-end event)))
@@ -1172,6 +1181,31 @@ static char *magick[] = {
(gud-remove nil)
(gud-break nil)))))))
+(defun gdb-mouse-toggle-breakpoint (event)
+ "Enable/disable breakpoint in left fringe/margin with mouse click."
+ (interactive "e")
+ (mouse-minibuffer-check event)
+ (let ((posn (event-end event)))
+ (if (numberp (posn-point posn))
+ (with-selected-window (posn-window posn)
+ (save-excursion
+ (goto-char (posn-point posn))
+ (if
+; (or
+ (posn-object posn)
+; (eq (car (fringe-bitmaps-at-pos (posn-point posn)))
+; 'breakpoint))
+ (gdb-enqueue-input
+ (list
+ (let ((bptno (get-text-property
+ 0 'gdb-bptno (car (posn-string posn)))))
+ (concat
+ (if (get-text-property
+ 0 'gdb-enabled (car (posn-string posn)))
+ "disable "
+ "enable ")
+ bptno "\n")) 'ignore))))))))
+
(defun gdb-breakpoints-buffer-name ()
(with-current-buffer gud-comint-buffer
(concat "*breakpoints of " (gdb-get-target-string) "*")))
@@ -1227,7 +1261,7 @@ static char *magick[] = {
'gdbmi-invalidate-breakpoints))
(defun gdb-toggle-breakpoint ()
- "Enable/disable the breakpoint at current line."
+ "Enable/disable breakpoint at current line."
(interactive)
(save-excursion
(beginning-of-line 1)
@@ -1707,7 +1741,7 @@ of the inferior. Non-nil means display the layout shown for
:version "21.4")
(defun gdb-many-windows (arg)
-"Toggle the number of windows in the basic arrangement."
+ "Toggle the number of windows in the basic arrangement."
(interactive "P")
(setq gdb-many-windows
(if (null arg)
@@ -1777,14 +1811,15 @@ buffers."
PUTSTRING is displayed by putting an overlay into the current buffer with a
`before-string' STRING that has a `display' property whose value is
PUTSTRING."
- (let ((gdb-string "x")
+ (let ((string (make-string 1 ?x))
(buffer (current-buffer)))
+ (setq putstring (copy-sequence putstring))
(let ((overlay (make-overlay pos pos buffer))
(prop (or dprop
(list (list 'margin 'left-margin) putstring))))
- (put-text-property 0 (length gdb-string) 'display prop gdb-string)
+ (put-text-property 0 (length string) 'display prop string)
(overlay-put overlay 'put-break t)
- (overlay-put overlay 'before-string gdb-string))))
+ (overlay-put overlay 'before-string string))))
;;from remove-images
(defun gdb-remove-strings (start end &optional buffer)
@@ -1793,25 +1828,30 @@ Remove only strings that were put in BUFFER with calls to `gdb-put-string'.
BUFFER nil or omitted means use the current buffer."
(unless buffer
(setq buffer (current-buffer)))
- (let ((overlays (overlays-in start end)))
- (while overlays
- (let ((overlay (car overlays)))
+ (dolist (overlay (overlays-in start end))
(when (overlay-get overlay 'put-break)
- (delete-overlay overlay)))
- (setq overlays (cdr overlays)))))
+ (delete-overlay overlay))))
-(defun gdb-put-breakpoint-icon (enabled)
+(defun gdb-put-breakpoint-icon (enabled bptno)
(let ((start (progn (beginning-of-line) (- (point) 1)))
- (end (progn (end-of-line) (+ (point) 1))))
+ (end (progn (end-of-line) (+ (point) 1)))
+ (putstring (if enabled "B" "b")))
+ (add-text-properties
+ 0 1 '(help-echo "mouse-1: set/clear bkpt, mouse-3: enable/disable bkpt")
+ putstring)
+ (if enabled (add-text-properties
+ 0 1 `(gdb-bptno ,bptno gdb-enabled t) putstring)
+ (add-text-properties
+ 0 1 `(gdb-bptno ,bptno gdb-enabled nil) putstring))
(gdb-remove-breakpoint-icons start end)
(if (display-images-p)
(if (>= (car (window-fringes)) 8)
(gdb-put-string
nil (1+ start)
`(left-fringe breakpoint
- ,(if enabled
- 'breakpoint-enabled-bitmap-face
- 'breakpoint-disabled-bitmap-face)))
+ ,(if enabled
+ 'breakpoint-enabled-bitmap-face
+ 'breakpoint-disabled-bitmap-face)))
(when (< left-margin-width 2)
(save-current-buffer
(setq left-margin-width 2)
@@ -1838,7 +1878,9 @@ BUFFER nil or omitted means use the current buffer."
(:type pbm :data
,breakpoint-disabled-pbm-data
:ascent 100))))))
- (+ start 1) nil 'left-margin))
+ (+ start 1)
+ putstring
+ 'left-margin))
(when (< left-margin-width 2)
(save-current-buffer
(setq left-margin-width 2)
@@ -1846,7 +1888,7 @@ BUFFER nil or omitted means use the current buffer."
(set-window-margins
(get-buffer-window (current-buffer) 0)
left-margin-width right-margin-width))))
- (gdb-put-string (if enabled "B" "b") (1+ start)))))
+ (gdb-put-string putstring (1+ start)))))
(defun gdb-remove-breakpoint-icons (start end &optional remove-margin)
(gdb-remove-strings start end)